@@ -1,6 +1,6 @@
 #include "EXTERN.h"
-#include "perl.h"
 #include "XSUB.h"
+#include "perl.h"
 #include <stdbool.h>
 #include <stdint.h>
 #include <uthash.h>
@@ -16,8 +16,8 @@ typedef unsigned __int64 uint64_t;
 #endif
 
 #ifdef INT64_DI
-typedef int int64_t __attribute__ ((__mode__(DI)));
-typedef unsigned int uint64_t __attribute__ ((__mode__(DTI)));
+typedef int int64_t __attribute__((__mode__(DI)));
+typedef unsigned int uint64_t __attribute__((__mode__(DTI)));
 #define HAVE_INT64
 #endif
 
@@ -26,8 +26,8 @@ typedef unsigned int uint64_t __attribute__ ((__mode__(DTI)));
 #endif
 
 #ifdef INT128_TI
-typedef int int128_t __attribute__ ((__mode__(TI)));
-typedef unsigned int uint128_t __attribute__ ((__mode__(TI)));
+typedef int int128_t __attribute__((__mode__(TI)));
+typedef unsigned int uint128_t __attribute__((__mode__(TI)));
 #define HAVE_INT128
 #endif
 
@@ -42,13 +42,12 @@ typedef unsigned __int128 uint128_t;
 #endif
 
 /* perl memory allocator does not guarantee 16-byte alignment */
-typedef int128_t int128_t_a8 __attribute__ ((aligned(8)));
-typedef uint128_t uint128_t_a8 __attribute__ ((aligned(8)));
+typedef int128_t int128_t_a8 __attribute__((aligned(8)));
+typedef uint128_t uint128_t_a8 __attribute__((aligned(8)));
 
 #define MATH_INT64_NATIVE_IF_AVAILABLE
-#include "perl_math_int64.h"
 #include "perl_math_int128.h"
-
+#include "perl_math_int64.h"
 
 typedef enum {
     MMDBW_SUCCESS,
@@ -135,49 +134,62 @@ typedef struct MMDBW_network_s {
     const uint8_t prefix_length;
 } MMDBW_network_s;
 
-typedef void (MMDBW_iterator_callback)(MMDBW_tree_s *tree,
-                                       MMDBW_node_s *node,
-                                       uint128_t network,
-                                       uint8_t depth,
-                                       void *args);
+typedef void(MMDBW_iterator_callback)(MMDBW_tree_s *tree,
+                                      MMDBW_node_s *node,
+                                      uint128_t network,
+                                      uint8_t depth,
+                                      void *args);
 
-/* *INDENT-OFF* */
-    /* --prototypes automatically generated by dev-bin/regen-prototypes.pl - don't remove this comment */
-    extern MMDBW_tree_s *new_tree(const uint8_t ip_version, uint8_t record_size,
-                                  MMDBW_merge_strategy merge_strategy,
-                                  const bool alias_ipv6,
-                                  const bool remove_reserved_networks);
-    extern void insert_network(MMDBW_tree_s *tree, const char *ipstr,
-                               const uint8_t prefix_length, SV *key_sv, SV *data,
-                               MMDBW_merge_strategy merge_strategy);
-    extern void insert_range(MMDBW_tree_s *tree, const char *start_ipstr,
-                             const char *end_ipstr, SV *key_sv, SV *data_sv,
-                             MMDBW_merge_strategy merge_strategy);
-    extern void remove_network(MMDBW_tree_s *tree, const char *ipstr,
-                               const uint8_t prefix_length);
-    extern SV *merge_hashes_for_keys(MMDBW_tree_s *tree, const char *const key_from,
-                                     const char *const key_into, MMDBW_network_s *network,
-                                     MMDBW_merge_strategy merge_strategy);
-    extern SV *lookup_ip_address(MMDBW_tree_s *tree, const char *const ipstr);
-    extern MMDBW_node_s *new_node();
-    extern void assign_node_numbers(MMDBW_tree_s *tree);
-    extern void freeze_tree(MMDBW_tree_s *tree, char *filename, char *frozen_params,
-                            size_t frozen_params_size);
-    extern MMDBW_tree_s *thaw_tree(char *filename, uint32_t initial_offset,
-                                   uint8_t ip_version, uint8_t record_size,
-                                   MMDBW_merge_strategy merge_strategy,
-                                   const bool alias_ipv6,
-                                   const bool remove_reserved_networks);
-    extern void write_search_tree(MMDBW_tree_s *tree, SV *output,
-                                  SV *root_data_type, SV *serializer);
-    extern uint32_t max_record_value(MMDBW_tree_s *tree);
-    extern void start_iteration(MMDBW_tree_s *tree,
-                                bool depth_first,
-                                void *args,
-                                MMDBW_iterator_callback callback);
-    extern uint128_t flip_network_bit(MMDBW_tree_s *tree, uint128_t network, uint8_t depth);
-    extern SV *data_for_key(MMDBW_tree_s *tree, const char *const key);
-    extern void free_tree(MMDBW_tree_s *tree);
-    extern void free_merge_cache(MMDBW_tree_s *tree);
-    /* --prototypes end - don't remove this comment-- */
-/* *INDENT-ON* */
+extern MMDBW_tree_s *new_tree(const uint8_t ip_version,
+                              uint8_t record_size,
+                              MMDBW_merge_strategy merge_strategy,
+                              const bool alias_ipv6,
+                              const bool remove_reserved_networks);
+extern void insert_network(MMDBW_tree_s *tree,
+                           const char *ipstr,
+                           const uint8_t prefix_length,
+                           SV *key_sv,
+                           SV *data,
+                           MMDBW_merge_strategy merge_strategy);
+extern void insert_range(MMDBW_tree_s *tree,
+                         const char *start_ipstr,
+                         const char *end_ipstr,
+                         SV *key_sv,
+                         SV *data_sv,
+                         MMDBW_merge_strategy merge_strategy);
+extern void remove_network(MMDBW_tree_s *tree,
+                           const char *ipstr,
+                           const uint8_t prefix_length);
+extern SV *merge_hashes_for_keys(MMDBW_tree_s *tree,
+                                 const char *const key_from,
+                                 const char *const key_into,
+                                 MMDBW_network_s *network,
+                                 MMDBW_merge_strategy merge_strategy);
+extern SV *lookup_ip_address(MMDBW_tree_s *tree, const char *const ipstr);
+extern MMDBW_node_s *new_node();
+extern void assign_node_numbers(MMDBW_tree_s *tree);
+extern void freeze_tree(MMDBW_tree_s *tree,
+                        char *filename,
+                        char *frozen_params,
+                        size_t frozen_params_size);
+extern MMDBW_tree_s *thaw_tree(char *filename,
+                               uint32_t initial_offset,
+                               uint8_t ip_version,
+                               uint8_t record_size,
+                               MMDBW_merge_strategy merge_strategy,
+                               const bool alias_ipv6,
+                               const bool remove_reserved_networks);
+extern void write_search_tree(MMDBW_tree_s *tree,
+                              SV *output,
+                              SV *root_data_type,
+                              SV *serializer);
+extern uint32_t max_record_value(MMDBW_tree_s *tree);
+extern void start_iteration(MMDBW_tree_s *tree,
+                            bool depth_first,
+                            void *args,
+                            MMDBW_iterator_callback callback);
+extern uint128_t
+flip_network_bit(MMDBW_tree_s *tree, uint128_t network, uint8_t depth);
+extern SV *data_for_key(MMDBW_tree_s *tree, const char *const key);
+extern void free_tree(MMDBW_tree_s *tree);
+extern void free_merge_cache(MMDBW_tree_s *tree);
